@@ -1,5 +1,3 @@
-# package Domain::Details;
-
 # PODNAME: Domain::Details
 # ABSTRACT: Domain class with DNS/SSL/WHOIS fields
 
@@ -8,8 +6,14 @@ use autouse 'Carp' => qw( carp croak );
 use autouse 'Data::Printer' => qw( p );
 use Object::Pad 0.78 ':experimental(init_expr)';
 
-class Domain::Details {
+package Domain::Details;
+# Without, PAUSE: No or no indexable package statements could be found in the distro
 
+# @formatter:off
+class Domain::Details :strict( params ) {
+# @formatter:on
+
+  use experimental qw( try );
   use Syntax::Keyword::Match;
   use Net::Domain::ExpireDate; # Function: expire_date
   use Domain::PublicSuffix;    # Method: get_root_domain
@@ -17,13 +21,16 @@ class Domain::Details {
   use Net::SSL::ExpireDate;
   use Net::DNS;
   use Geo::IP;
-  use Term::ANSIColor;
-  use experimental qw( try );
+  use Term::ANSIColor qw( colorstrip );
+  use Clipboard; # Class method: copy_to_all_selections
 
   # @formatter:off
 
   field $domain :param :reader;
-  field $description :accessor;
+
+
+  field $description :param :accessor = undef;
+
 
   method $whois_expiration ( $format //= '%B %d, %Y' ) {
     my $publicsuffix = Domain::PublicSuffix -> new;
@@ -38,56 +45,67 @@ class Domain::Details {
         $ssl -> expire_date -> day ,
         $ssl -> expire_date -> year;
     }
-    catch($message) {
-      return undef;
-    }
+    catch( $message ) { undef }
   }
-
-  field $expiration :reader { $self -> $whois_expiration };
-  field $ssl_expiration :reader { $self -> $ssl_expiration };
-
-  method print_ssl :common ( $domain ) {
-  # @formatter:on
+  method $ssl_issue ( $format //=  "%s %s, %s" ) {
     my $ssl = Net::SSL::ExpireDate -> new( https => $domain );
     try {
-      my %date = ( # Class: DateTime
-        expire => $ssl -> expire_date ,
-        issue  => $ssl -> begin_date
-      );
-      printf( colored( [ 'red' ] , "SSL Expiry: %s %s, %s\n" ) , $date{expire} -> month_name , $date{expire} -> day , $date{expire} -> year );
-      printf( colored( [ 'green' ] , "SSL Issue: %s %s, %s\n" ) , $date{issue} -> month_name , $date{issue} -> day , $date{issue} -> year );
-      say colored( [ 'bright_red' , 'bold' ] , 'EXPIRES IN 14 DAYS' )
-        if defined $ssl -> is_expired( '14 days' );
-    }
-    catch($message) {
-      warn "SSL: $message";
+      return sprintf $format ,
+        $ssl -> begin_date -> month_name ,
+        $ssl -> begin_date -> day ,
+        $ssl -> begin_date -> year;
     }
+    catch( $message ) { undef }
   }
-  # @formatter:off
-  method print_dns :common ( $domain ) {
-  # @formatter:on
-    my $dns = Net::DNS::Resolver -> new;
+  method $ssl_expires_soon ($format //= '14 days' ) {
+    my $ssl = Net::SSL::ExpireDate -> new( https => $domain );
+    try {
+      $ssl -> is_expired( $format );
+    }
+  catch ( $message ) { undef }
 
-    my $a = $dns -> query( $domain , 'A' ); # may return Net::DNS::RR::CNAME (w/ cname method)
+  }
+
+  field $whois_expiration :reader { $self -> $whois_expiration };
+
+
+  field $ssl_expiration :reader { $self -> $ssl_expiration };
+
+
+
+  field $ssl_issue :reader { $self -> $ssl_issue };
+
+
+
+  field $ssl_expires_soon :reader { $self -> $ssl_expires_soon };
+
+
+  method dns ( ) {
+  # @formatter:on
+    my $resolver = Net::DNS::Resolver -> new;
+    my $geo = Geo::IP -> open( '/usr/share/GeoIP/GeoIP.dat' );
+    # Set path explicitly because Perlbrew 5.36 on Debian fails to open for searching in /usr/local when Geo::IP is being installed with "cpan"
+    # Installing the Debian package libgeo-ip-perl probably fixes that
+
+    my ( $cname , $ptr );
+
+    my $a = $resolver -> query( $domain , 'A' );
     my @a = $a -> answer if defined $a;
 
-    my $cname;
-
-    my $mx = $dns -> query( $domain , 'MX' ); # class: Net::DNS::Packet
+    my $mx = $resolver -> query( $domain , 'MX' );
     my @mx = $mx -> answer if defined $mx;
 
-    my $ns = $dns -> query( $domain , 'NS' );
+    my $ns = $resolver -> query( $domain , 'NS' );
     my @ns = $ns -> answer if defined $ns;
 
-    my $ptr;
-
-    my $txt = $dns -> query( $domain , 'TXT' );
+    my $txt = $resolver -> query( $domain , 'TXT' );
     my @txt = $txt -> answer if defined $txt;
 
-    my $soa = $dns -> query( $domain , 'SOA' );
+    my $soa = $resolver -> query( $domain , 'SOA' );
     my @soa = $soa -> answer if defined $soa;
 
     my $answer;
+
     my %dns = (
       a     => [] ,
       cname => '' ,
@@ -95,22 +113,16 @@ class Domain::Details {
       mx    => [] ,
       ns    => [] ,
       txt   => [] ,
-    ); # TODO: %dns_colors
+    ); # to push individual record values here
 
-    my $geo = Geo::IP -> open( '/usr/share/GeoIP/GeoIP.dat' );
-    # Debian, perlbrew 5.36 fails to open for searching in /usr/local when Geo::IP is being installed with cpan
-    # libgeo-ip-perl Debian package probably patches it
-    # my $geo = Geo::IP->new(GEOIP_MEMORY_CACHE); # faster
-
-    for my $record ( @a , @mx , @ns , @txt , @soa ) # Net::DNS::RR object list
-    {
+    for my $record ( @a , @mx , @ns , @txt , @soa ) {
       match( $record -> type : eq )
       {
         case( 'A' )
         {
           $answer .= sprintf( "A:\t%s (%s)\n" , $record -> address , $geo -> country_code_by_addr( $record -> address ));
           push( $dns{a} -> @* , $record -> address );
-          $ptr = $dns -> query( $record -> address , 'PTR' ); # Net::DNS::Packet
+          $ptr = $resolver -> query( $record -> address , 'PTR' ); # Net::DNS::Packet
           if ( $ptr ) {
             my @ptr = $ptr -> answer; # [ Net::DNS:RR, ... ]
             $answer .= Term::ANSIColor::colored( [ 'bright_cyan' ] , sprintf( "P:\t%s (%s)\n" , $ptr[0] -> ptrdname , $geo -> country_code_by_name( $ptr[0] -> ptrdname )));
@@ -154,13 +166,26 @@ class Domain::Details {
 
     }
 
-    # say Data::Dumper::Dumper %dns;
-
     $answer = $answer . $cname if defined $cname;
-    # return $answer;
-    say $answer;
+    return $answer;
   }
 
+
+  # @formatter:off
+  method summary () {
+  # @formatter:on
+    my $summary = <<~ "SUMMARY";
+    SSL Expiration   : $ssl_expiration @{[$ssl_expires_soon ? '(Expires Soon)' : '' ]}
+    SSL Issue        : $ssl_issue
+    WHOIS Expiration : $whois_expiration
+
+    DNS              :
+
+    @{[$self->dns]}
+    SUMMARY
+    say $summary;
+    Clipboard -> copy_to_all_selections( colorstrip $summary );
+  }
 }
 
 __END__
@@ -175,7 +200,53 @@ Domain::Details - Domain class with DNS/SSL/WHOIS fields
 
 =head1 VERSION
 
-version 0.230310
+version 0.230320
+
+=head1 METHODS
+
+=head2 domain
+
+Return the current domain as created with the C<new> constructor
+
+=head2 description
+
+Return or set an optional description (comment) on the domain object
+
+=head2 whois_expiration
+
+Returns domain's expiration date using the L<Net::ExpireDate> module's C<expire_date> function
+
+Derives the root domain using L<Domain::PublicSuffix> class' C<get_root_domain> method
+
+Accepts optional argument to specify the format the date is returned in
+
+=head2 ssl_expiration
+
+Return the SSL expiration date using L<Net::SSL::ExpireDate> class' C<expire_date> constructor returning a L<DateTime> object
+
+Accepts an argument to loosely set the date format as Year, Month, Day in C<sprintf> syntax
+
+=head2 ssl_issue
+
+Return the SSL issue date using L<Net::SSL::ExpireDate> class' C<begin_date> constructor returning a L<DateTime> object
+
+Accepts an argument to loosely set the date format as Year, Month, Day in C<sprintf> syntax
+
+=head2 ssl_expires_soon
+
+Return a boolean indicating if the SSL expires within the time specified
+
+Defaults to 14 days, ie. 2 weeks which is a normal renewal date
+
+=head2 dns
+
+L<Net::DNS> records (A, CNAME, MX, NS, TXT, and SOA) with with L<Geo::IP>
+
+Uses L<Syntax::Keyword::Match> to topicalize C<$record -> type>
+
+=head2 summary
+
+Output summary, and copy it into the clipboard stripping colors with L<C<colorstrip>|Term::ANSIColor/colorstrip(STRING[, STRING ...])>
 
 =head1 AUTHOR
 
